#----------------------------------------------------------------------------
#
# SavSPIbkgMdl
# 
# This script should be run only after a satisfactory soultion to the source(s) + 
# background deconvlution is achieved. It sill write out the inferred background 
# model paramaters. It als ASSUMES THAT SPIdata HAS BEEN USED to initialize the
# data and responses. This is because it will use the temporary file created by
# SPIdata to align the appropriate model parameters with spectrum/group number
# which will be used in the background calculation. 
#
#
#   Inputs:
#              bkgMdlID         XSPEC numonic for background model, e.g. "bkg" (==default)
#              SPIbkgMdl        name of SPI background model, e.g. "spibkg_lo" (==default)
#              ofile            name of output file; default = "SPIbkgMdl.params"
#              infile           name of input file created by SPIdata 
#                               (def="SPIdata_session.tmp" 
#              
#
#   Examples:
#
#	1) Suppose the we've now satisfactorily completed a SPI-XSPEC model fitting 
#	session, for which we had initated the background modeling step as follows:
#
#	XSPEC> model 2:bkg spiblg_lo
#	...
#	...
#
#	We then save the parameter values for our model fit (and some related information
#	using SPIbkgMdl as follows:
#
#	XSPEC> SPIbkgMdl bkg spibkg_lo mySPIbkgParams.dat
#
#	The file mySPIbkgParams.dat is then used with the "spibkgsubtrct: FTOOL to 
# 	produce a background subtracted pha type II data file. That background subtracted
#	spectral data can then be read into XSPEC for subsequent manipulation (e.g. plotting, 
#	or joint fitting/plotting with other instrument data sets).
#
#
#      C.R. Shrader,  Code 661, NASA/GSFC  06/2004
#
#----------------------------------------------------------------------------

proc SavBkgMdl { {bkgMdlID "bkg"} {SPIbkgMdl "spibkg_lo"} {ofile "SPIbkgMdl.params"} 
		 {infile "SPIdata_session.tmp"} } {

    if { $bkgMdlID == "-h" }  {

      puts "\nSavSPIbkgMdl bkgMdlID SPIbkgMdl outfile infile Ndet\n"
      puts "This script should be run only after a satisfactory soultion to the source(s) + "
      puts "background deconvlution is achieved. It sill write out the inferred background "
      puts "model paramaters. It als ASSUMES THAT SPIdata HAS BEEN USED to initialize the"
      puts "data and responses. This is because it will use the temporary file created by"
      puts "SPIdata to align the appropriate model parameters with spectrum/group number"
      puts "which will be used in the background calculation. \n"
    
      puts "Inputs:"
      puts "-------"
      puts "bkgMdlID         XSPEC numonic for background model, e.g. bkg (==default)"
      puts "SPIbkgMdl        name of SPI background model, e.g. spibkg_lo (==default)"
      puts "ofile            name of output file; default = SPIbkgMdl.params"
      puts "infile           name of input file created by SPIdata "
      puts "                 (def=SPIdata_session.tmp" 
#              
#
      set result " "
      return $result
    }
#
# initailize a few variables:

    if { $SPIbkgMdl == "spibkg_lo" } {
	set Npar 11
    }

    if { $SPIbkgMdl == "spibkg_med" } {
 	set Npar 26
    }

    if { $SPIbkgMdl == "spibkg_hi" } {
	set Npar 51
    }


# open input file (default is "SPIdata_session.tmp" created by SPIdata

    set infil [open $infile "r"]
    set ofil  [open $ofile  "w"]

# write number of spectra and number of background model parameters
# to output fil

    puts $ofil "$Npar "
    tclout datasets
    set Nspec [lindex $xspec_tclout 0]
    puts $ofil "$Nspec "


# new read in line be line, skipping the header stuff

    gets $infil tmp
    gets $infil tmp
    gets $infil tmp
    gets $infil tmp
    gets $infil tmp
    gets $infil tmp

    while { ![eof $infil] } {
	gets $infil tmp 
	set grpIdx   [lindex  $tmp  0]
	set datIdx   [lindex  $tmp  1]
	set rowIdx   [lindex  $tmp  2]
#
# for each input row, obtain (indexed) model parameters and write
# to file - data extraction is accomplished with the XSPEC "tclout" command
# output is row index, parameters{1,...N}


	if { $grpIdx > 0 } {
	set OffSet [expr [expr $grpIdx - 1] * $Npar]

	puts -nonewline $ofil "$rowIdx"
 	for {set j 1} {$j <= $Npar} {incr j} {
	    set k [expr $j + $OffSet]
	    tclout  param $bkgMdlID:$k 
	    set param($j) [lindex $xspec_tclout 0]
	    puts  -nonewline $ofil  " $param($j)  "
	}
	    puts $ofil " "
	}
    }
    close $infil
    close $ofil
}