#----------------------------------------------------------------------------
#
# getModID
# 
# this subroutine script reads uses the XSPEC tclout command to get the name of the SPI 
# background model (for now either spibkg_lo, spibkg_med, or spibkg_hi), and the associated
# XSPEC model name (or numonic), e.g. "bkg"
#
# this informatino can then be saved to a session log and reduce the amount of
# command line input needed for other scripts 
#   Inputs:
#
#   Outputs:
#                   ModID      string variable, to be assigned XSPEC model ID (nuemonic)
#                   ModNam     XSPEC model name, e.g. "spibkg_lo"
#
#
#      C.R. Shrader,  Code 661, NASA/GSFC  11/2004
#
#----------------------------------------------------------------------------


proc getModID { {ModID "bkg"} {ModNam "spibkg_lo"} } {

#
# get model information, and parse backound model nemonic & 
# model name into strings


# use tclout command to get model info

	tclout model
#
	set jj -1
	set ii  0
#
	while { $ii != -99 } {
	 incr jj	 
    	 set ModNam [lindex $xspec_tclout $jj] 
	 set ModNam [string range $ModNam 0 5]
	 if { $ModNam == "spibkg" } {
	  set ii -99 }
	}
#
# now search $xspec_tclout variable to find model mane and ID

	set ModID  [lindex $xspec_tclout [expr $jj -1]]
	set ModNam [lindex $xspec_tclout $jj ]
#
# now get rid of appended ":"

	set jj -1
	set ii  0
	while {$ii !=-99 } {
	    incr jj
	    set tmp [string range $ModID $jj $jj]
	    if { $tmp == ":" } {
		set ii -99
		set jj [expr $jj-1]
		set ModID [string range $ModID 0 $jj]
	    }
	}
    }