#----------------------------------------------------------------------------
#
# procedure get_spec_rages reads a simple ascii file of the format
#
#  Spec_rnge_strt(i),  spec_rnge_stop(1)
#  ...
#  Spec_rnge_strt(n),  spec_rnge_stop(n)
#
#  note the comma-delimted fields
#
#
# where start & Stop ranges define the ranges of row numers (spectra) to be 
# used in the analysis. The ordered spectral row numbers are returned in 
# the array AllRows; this might look like , e.g. [0,...18,76,...112,...]
# the total number of spectra is also returned in TotSpec
#
# Note that for the SPIuntie and SPIfreeze functions
# to work properly, whole science windows should be used (i.e. the
# intervals S1->S2 contain multiples of the 19 SPI detectors
#
#  C.R. Shrader  NASA/GSFC  Code 661    05/2004
#
#
#----------------------------------------------------------------------------


proc get_spec_ranges { {filnam -99} {TotSpec 0} {AllRows 0} } {

     if { $filnam == -99 }  {

      puts "\n get_spec_ranges requires 3 arguments:"
      puts "\n filename Number-of-spec Row-Indices"
      puts "\n   where the latter contain return values"
      set result " "
      return $result
    }

#
# return values: AllSpec == ordered array of all spectral row numbers
#                TotSpec == number of spectra (i.e. dimension of AllSpec)

    upvar $AllRows AllSpec
    upvar $TotSpec Nspec

#
# initialize array index counter and open the file

    set i 0
    set k 0

    set Intrvl 0
    set infil [open $filnam "r"]
    set Nspec 0


#
# read line-by-line until end of file, and parse start - end values
# also, store spectral row numbers consecutively ni an array "AllSpec"
# to be passed back to the main program

    while { ![eof $infil] } {
	gets $infil range 
     
	set Spec_rnge_strt($i) [lindex [split $range , ] 0]
	set Spec_rnge_stop($i) [lindex [split $range , ] 1]

	set Intrvl [expr $Spec_rnge_stop($i) + 1 - $Spec_rnge_strt($i)]
	set Nspec [expr $Nspec + $Intrvl]

	for {set j 0} {$j < $Intrvl} {incr j} {
	    set AllSpec([expr $j +$k])  [expr $Spec_rnge_strt($i)+$j]
	}
        
     set k [expr $k + $Intrvl]
     incr i
    }
     close $infil
 }
